@@ -7,8 +7,11 @@ Stacksearch is a simple tool aimed for people who never want to leave the termin
 Stacksearch can also search other Stack Exchange websites, not just StackOverflow.
 """
 
-__version__ = "1.3.8"
 
-__author__ = ["Bryan Hu", "KomodoKode"]
+__version__ = "1.3.10"
+
+__author__ = "Bryan Hu"
 
 __all__ = ["__main__", "Search"]
+
+__credits__: str = ["KomodoKode"]
